@@ -1,5 +1,6 @@
 import logging
 from json.decoder import JSONDecodeError
+from typing import Dict
 
 import requests
 from outcache import Cache
@@ -15,7 +16,7 @@ class BeatSaver:
     def __init__(self):
         self.log = logging.getLogger(__name__)
 
-    def _process_url(self, url):
+    def _process_url(self, url: str) -> Dict:
         response = Common.request(requests.get, url, timeout=self.TIMEOUT)
 
         try:
@@ -27,19 +28,19 @@ class BeatSaver:
         return data
 
     @Cache(hours=24)
-    def _get_song_by_hash(self, song_hash: str):
+    def _get_map_by_hash(self, song_hash: str):
         return self._process_url(f"{self._url}/maps/hash/{song_hash}")
 
-    def get_song_by_hash(self, song_hash: str) -> MapDetail:
-        song_info = self._get_song_by_hash(song_hash)
+    def get_map_by_hash(self, song_hash: str) -> MapDetail:
+        map_info = self._get_map_by_hash(song_hash)
 
-        return MapDetail.from_dict(song_info)
+        return MapDetail.from_dict(map_info)
 
     @Cache(hours=24)
-    def _get_song_by_key(self, song_key):
+    def _get_map_by_key(self, song_key: str):
         return self._process_url(f"{self._url}/maps/beatsaver/{song_key}")
 
-    def get_song_by_key(self, song_key) -> MapDetail:
-        song_info = self._get_song_by_key(song_key)
+    def get_map_by_key(self, song_key: str) -> MapDetail:
+        map_info = self._get_map_by_key(song_key)
 
-        return MapDetail.from_dict(song_info)
+        return MapDetail.from_dict(map_info)
